@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Page::Parse;
 {
-  $Mojito::Page::Parse::VERSION = '0.22';
+  $Mojito::Page::Parse::VERSION = '0.23';
 }
 use 5.010;
 use Moo;
@@ -19,11 +19,10 @@ Mojito::Page::Parse - turn page source into a page structure
 has 'page' => (
     is       => 'rw',
     isa      => Value,
-#    required => 1,
 );
 has 'sections' => (
     is      => 'ro',
-    isa     => AHRef,
+    isa     => ArrayRef[HashRef],
     lazy    => 1,
     builder => 'build_sections',
 );
@@ -33,14 +32,6 @@ has 'page_structure' => (
     lazy    => 1,
     builder => 'build_page_structure',
 );
-#has 'title' => (
-#    is => 'ro',
-#
-#    #    isa     => 'Str',
-#    lazy => 1,
-#    default =>
-#      sub { return substr( $_[0]->stripper->parse( $_[0]->page ), 0, 24 ); },
-#);
 has 'default_format' => (
     is => 'rw',
     isa     => Value,
@@ -216,7 +207,6 @@ sub build_page_structure {
 
     my $return = {
         sections       => $self->sections,
-#        title          => $self->title,
         default_format => $self->default_format,
 
         #        created        => '1234567890',
